camelot.camelot.view.search

Package camelot :: Package camelot :: Package view :: Module search |
[hide private]
[frames] | no frames]

# Module search

source code

Helper functions to search through a collection of entities

Functions | [hide private]
create_entity_search_query_decorator(admin, text) create a query decorator to search through a collection of entities | source code

Variables | [hide private]
| logger = `logging.getLogger('camelot.view.search')`

Function Details | [hide private]

### create_entity_search_query_decorator(admin, text) | source code
create a query decorator to search through a collection of entities Parameters: `admin` - the admin interface of the entity `text` - the text to search for Returns: a function that can be applied to a query to make the query filter only the objects related to the requested text